@@ -24,9 +24,9 @@ shinyUI(dashboardPage(skin = "black",
                       # Tricky way of placing elements in dashboardHeader, expects a tag element of type li and class dropdown, 
                       # so we can pass such elements instead of dropdownMenus
                       dashboardHeader(title = "MEM dashboard",
-                                      tags$li(paste("memapp v",packageVersion("memapp"),", code under GPLv2 at",sep=""),
+                                      tags$li(paste("memapp v",packageVersion("memapp")," and mem v",packageVersion("mem"),", code under GPLv2 at",sep=""),
                                               class = "dropdown"),
-                                      tags$li(a(href = 'https://github.com/lozalojo/memapp',
+                                      tags$li(a(href = 'https://github.com/lozalojo/',
                                                 target="_blank",
                                                 img(src = 'GitHub_Logo.png',
                                                     title = "José E. Lozano", height = "30px"),
@@ -187,11 +187,11 @@ shinyUI(dashboardPage(skin = "black",
                                      bsPopover(id = "colEpidemicStart", title = "Epidemic start", content = "Color of the point of the epidemic start marker.", placement = "left", trigger = "hover", options = list(container = "body")),
                                      selectInput("colEpidemicStop", h6("Epidemic end", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",colors()), size=1, selectize = FALSE, selected = "default"),
                                      bsPopover(id = "colEpidemicStop", title = "Epidemic end", content = "Color of the point of the epidemic end marker.", placement = "left", trigger = "hover", options = list(container = "body")),
-                                     selectInput("colThresholds", h6("Thresholds palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info)), size=1, selectize = FALSE, selected = "default"),
+                                     selectInput("colThresholds", h6("Thresholds palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info),colors()), size=1, selectize = FALSE, selected = "default"),
                                      bsPopover(id = "colThresholds", title = "Thresholds palette", content = "Palette used to generate color for epidemic and intensity thresholds.", placement = "left", trigger = "hover", options = list(container = "body")),
-                                     selectInput("colSeasons", h6("Seasons palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info)), size=1, selectize = FALSE, selected = "default"),
+                                     selectInput("colSeasons", h6("Seasons palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info),colors()), size=1, selectize = FALSE, selected = "default"),
                                      bsPopover(id = "colSeasons", title = "Seasons palette", content = "Palette used to generate the colors of the lines of the series graphs and other graphs with multiple lines.", placement = "left", trigger = "hover", options = list(container = "body")),
-                                     selectInput("colEpidemic", h6("Timing palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info)), size=1, selectize = FALSE, selected = "default"),
+                                     selectInput("colEpidemic", h6("Timing palette", tags$style(type = "text/css", "#q1 {vertical-align: top;}")), choices = c("default",rownames(brewer.pal.info),colors()), size=1, selectize = FALSE, selected = "default"),
                                      bsPopover(id = "colEpidemic", title = "Timing palette", content = "Palette used to generate the colors of the points of pre, epidemic and post markers in timing graphs.", placement = "left", trigger = "hover", options = list(container = "body"))
                                    ),
                                    box(
